@@ -17,11 +17,6 @@ O = TypeVar("O", bound=Option)
 class AbstractEntityRequestBuilder(AbstractRequestBuilder, Generic[R]):
     """Entity Request Builder Type"""
 
-    @property
-    @abstractmethod
-    def generic_type(self) -> Type[R]:
-        """Gets the value of the generic type provided"""
-
     @property
     @abstractmethod
     def request(self) -> R:
